aboutsummaryrefslogtreecommitdiff
path: root/sys/cmd/rc/parse.h
diff options
context:
space:
mode:
authorNicholas Noll <nbnoll@eml.cc>2021-10-19 14:16:54 -0700
committerNicholas Noll <nbnoll@eml.cc>2021-10-19 14:16:54 -0700
commit6d50d5b97d49a74a8faf587ec2bbf234626adf0c (patch)
treeff09e03ad96fc873b10027120f38a2ae382ae916 /sys/cmd/rc/parse.h
parent2b53bca326decd50012883f0cff3b5316a3e100d (diff)
Feat(rc): added subshell commands and cd builtin
Slowly chipping away at a decent feature list. Subshell commands are executed by @{ ... }.
Diffstat (limited to 'sys/cmd/rc/parse.h')
-rw-r--r--sys/cmd/rc/parse.h36
1 files changed, 19 insertions, 17 deletions
diff --git a/sys/cmd/rc/parse.h b/sys/cmd/rc/parse.h
index 85be043..b42cc2b 100644
--- a/sys/cmd/rc/parse.h
+++ b/sys/cmd/rc/parse.h
@@ -59,14 +59,15 @@ extern int yydebug;
Tif = 260, /* Tif */
Telse = 261, /* Telse */
Tbang = 262, /* Tbang */
- Targs = 263, /* Targs */
- Tindex = 264, /* Tindex */
- Tbasic = 265, /* Tbasic */
- Tparen = 266, /* Tparen */
- Tblock = 267, /* Tblock */
- Twhile = 268, /* Twhile */
- Tcount = 269, /* Tcount */
- Tflat = 270 /* Tflat */
+ Tsubshell = 263, /* Tsubshell */
+ Targs = 264, /* Targs */
+ Tindex = 265, /* Tindex */
+ Tbasic = 266, /* Tbasic */
+ Tparen = 267, /* Tparen */
+ Tblock = 268, /* Tblock */
+ Twhile = 269, /* Twhile */
+ Tcount = 270, /* Tcount */
+ Tflat = 271 /* Tflat */
};
typedef enum yytokentype yytoken_kind_t;
#endif
@@ -80,14 +81,15 @@ extern int yydebug;
#define Tif 260
#define Telse 261
#define Tbang 262
-#define Targs 263
-#define Tindex 264
-#define Tbasic 265
-#define Tparen 266
-#define Tblock 267
-#define Twhile 268
-#define Tcount 269
-#define Tflat 270
+#define Tsubshell 263
+#define Targs 264
+#define Tindex 265
+#define Tbasic 266
+#define Tparen 267
+#define Tblock 268
+#define Twhile 269
+#define Tcount 270
+#define Tflat 271
/* Value type. */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -97,7 +99,7 @@ union YYSTYPE
struct Tree *tree;
-#line 101 "sys/cmd/rc/parse.h"
+#line 103 "sys/cmd/rc/parse.h"
};
typedef union YYSTYPE YYSTYPE;